@@ -457,29 +457,29 @@ class MainApplication(tk.Frame):
 
         """Switches between light and dark theme
         """
-        
+
         if theme == "light":
             self.parent.tk.call("set_theme", "light")
             self.logocanvas.place_forget()
             self.logocanvas.configure(background="#ffffff")
             self.parent.configure(background="#ffffff")
             self.logocanvas.place(
-            relx=0.41233, rely=0.3441, relheight=1, relwidth=1,
-        )
-            
+                relx=0.41233, rely=0.3441, relheight=1, relwidth=1,
+            )
+
             if self.filenames != []:
                 self.show_preview()
 
         else:
             # Set dark theme
             self.parent.tk.call("set_theme", "dark")
-            
+
             self.parent.configure(background="#363636")
             self.logocanvas.place_forget()
             self.logocanvas.configure(background="#333333")
             self.logocanvas.place(
-            relx=0.41233, rely=0.3441, relheight=1, relwidth=1,
-        )
+                relx=0.41233, rely=0.3441, relheight=1, relwidth=1,
+            )
             if self.filenames != []:
                 self.logocanvas.place_forget()
                 self.show_preview()
@@ -567,6 +567,7 @@ class MainApplication(tk.Frame):
         errlimmax = self.DoseFigureHandler.errlimmax
         initial_limits = self.initial_limits
         current_limits = [self.slidervars[0].get(), self.slidervars[1].get()]
+        dark = self.dark.get()
         try:
             self.slider.submit()
             self.slider.window.destroy()
@@ -577,6 +578,9 @@ class MainApplication(tk.Frame):
         self.parent.config(menu=None)
         self.profile.set_attribute("language", language)
         self.__init__(self.parent)
+        if dark == True:
+            self.switchtheme("dark")
+            self.dark.set(True)
         if plots != []:
             self.filenames = filenames
             self.DoseFigureHandler.plots = plots
@@ -636,7 +640,6 @@ class MainApplication(tk.Frame):
 
         """Closes the current project
         """
-
         self.canvas.place_forget()
         self.filemenu.entryconfig(0, state=tk.NORMAL)
         self.filemenu.entryconfig(1, state=tk.NORMAL)
@@ -650,7 +653,10 @@ class MainApplication(tk.Frame):
         self.normmenu.entryconfig(13, state=tk.DISABLED)
         self.menubar.delete(4, 5)
         self.filenames = []
-        self.canvas.itemconfig(self.image_on_canvas, image=None)
+        try:
+            self.canvas.itemconfig(self.image_on_canvas, image=None)
+        except Exception:
+            pass
         self.DoseFigureHandler.flush()
         self.DoseFigureHandler.plots = []
         self.diffplot.set(False)
@@ -1242,28 +1248,34 @@ class MainApplication(tk.Frame):
         for index, box in enumerate(self.rename_boxes):
             if e != None:
                 bbox = self.canvas.bbox(box)
-                if bbox[0] < e.x and bbox[2] > e.x and bbox[1] < e.y and bbox[3] > e.y:
-                    if index == len(self.rename_boxes) - 1:
-                        if self.xlimmenu == False:
-                            self.change_xrange()
-                        else:
-                            newname = sd.askstring(
-                                "",
-                                self.text.changefilename[self.lang],
-                                initialvalue=self.DoseFigureHandler.xlabel,
-                            )
-                            if newname != None:
-                                self.DoseFigureHandler.xaxisname = newname
-                                self.show_preview()
-                        return
-                    newname = sd.askstring(
-                        "",
-                        self.text.changefilename[self.lang],
-                        initialvalue=self.DoseFigureHandler.plots[index].filename,
-                    )
-                    if newname != None:
-                        self.DoseFigureHandler.plots[index].filename = newname
-                        self.show_preview()
+                if bbox != None:
+                    if (
+                        bbox[0] < e.x
+                        and bbox[2] > e.x
+                        and bbox[1] < e.y
+                        and bbox[3] > e.y
+                    ):
+                        if index == len(self.rename_boxes) - 1:
+                            if self.xlimmenu == False:
+                                self.change_xrange()
+                            else:
+                                newname = sd.askstring(
+                                    "",
+                                    self.text.changefilename[self.lang],
+                                    initialvalue=self.DoseFigureHandler.xlabel,
+                                )
+                                if newname != None:
+                                    self.DoseFigureHandler.xaxisname = newname
+                                    self.show_preview()
+                            return
+                        newname = sd.askstring(
+                            "",
+                            self.text.changefilename[self.lang],
+                            initialvalue=self.DoseFigureHandler.plots[index].filename,
+                        )
+                        if newname != None:
+                            self.DoseFigureHandler.plots[index].filename = newname
+                            self.show_preview()
 
     def check_right_click(self, e):
 
